@@ -15,3 +15,6 @@ class ModelName(Model):
         # Override the parent class default properties
         self.table = '_table_name'
         self.primary_key = 'id'
+
+        # Repair the database
+        self.repair = {}
